@@ -1,11 +1,5 @@
 package MyCPAN::Indexer::Notes;
 
-use strict;
-use warnings;
-
-use vars qw($VERSION);
-$VERSION = '1.28_10';
-
 =head1 NAME
 
 MyCPAN::Indexer::Notes - Tiny class for MyCPAN component note passing
@@ -173,7 +167,7 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2008-2010, brian d foy, All Rights Reserved.
+Copyright (c) 2008-2009, brian d foy, All Rights Reserved.
 
 You may redistribute this under the same terms as Perl itself.
 
